@@ -1,4 +1,4 @@
-/* $Id: expense.c,v 1.56 2008/05/25 09:46:20 rousseau Exp $ */
+/* $Id: expense.c,v 1.62 2008/06/18 02:40:02 rikster5 Exp $ */
 
 /*******************************************************************************
  * expense.c
@@ -54,10 +54,6 @@
 #define MAX_PAYMENTS       8
 #define MAX_CURRENCYS     34
 
-/* this is alredy defined in utils.h with a different value */
-#undef  CATEGORY_ALL
-#define CATEGORY_ALL 200
-
 #define CONNECT_SIGNALS    400
 #define DISCONNECT_SIGNALS 401
 
@@ -159,18 +155,14 @@ static GtkAdjustment *adj_mon, *adj_day, *adj_year;
 static GtkWidget *entry_amount;
 static GtkWidget *entry_vendor;
 static GtkWidget *entry_city;
-static GtkWidget *text_attendees;
-static GtkWidget *pane;
+static GtkWidget *pane=NULL;
 #ifndef ENABLE_STOCK_BUTTONS
 static GtkAccelGroup *accel_group;
 #endif
-#ifdef ENABLE_GTK2
-static GObject   *text_attendees_buffer;
-#endif
-static GtkWidget *text_note;
-#ifdef ENABLE_GTK2
-static GObject   *text_note_buffer;
-#endif
+static GtkWidget *attendees;
+static GObject   *attendees_buffer;
+static GtkWidget *note;
+static GObject   *note_buffer;
 
 /* This is the category that is currently being displayed */
 static int show_category;
@@ -214,6 +206,7 @@ int plugin_unpack_cai_from_ai(struct CategoryAppInfo *cai,
    
    jp_logf(JP_LOG_DEBUG, "unpack_expense_cai_from_ai\n");
 
+   memset(&ai, 0, sizeof(ai));
    r = unpack_ExpenseAppInfo(&ai, ai_raw, len);
    if (r <= 0) {
       jp_logf(JP_LOG_DEBUG, "unpack_ExpenseAppInfo failed %s %d\n", __FILE__, __LINE__);
@@ -374,17 +367,10 @@ static void connect_changed_signals(int con_or_dis)
                          GTK_SIGNAL_FUNC(cb_record_changed), NULL);
       gtk_signal_connect(GTK_OBJECT(entry_city), "changed",
                          GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#ifdef ENABLE_GTK2
-      g_signal_connect(text_attendees_buffer, "changed",
+      g_signal_connect(attendees_buffer, "changed",
                          GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-      g_signal_connect(text_note_buffer, "changed",
+      g_signal_connect(note_buffer, "changed",
                          GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#else
-      gtk_signal_connect(GTK_OBJECT(text_attendees), "changed",
-                         GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-      gtk_signal_connect(GTK_OBJECT(text_note), "changed",
-                         GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#endif
    }
 
    /* DISCONNECT */
@@ -432,17 +418,10 @@ static void connect_changed_signals(int con_or_dis)
                                     GTK_SIGNAL_FUNC(cb_record_changed), NULL);
       gtk_signal_disconnect_by_func(GTK_OBJECT(entry_city),
                                     GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#ifdef ENABLE_GTK2
-      g_signal_handlers_disconnect_by_func(text_attendees_buffer,
+      g_signal_handlers_disconnect_by_func(attendees_buffer,
                                     GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-      g_signal_handlers_disconnect_by_func(text_note_buffer,
+      g_signal_handlers_disconnect_by_func(note_buffer,
                                     GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#else
-      gtk_signal_disconnect_by_func(GTK_OBJECT(text_attendees),
-                                    GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-      gtk_signal_disconnect_by_func(GTK_OBJECT(text_note),
-                                    GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#endif
    }
 }
 
@@ -645,15 +624,8 @@ static void clear_details()
    gtk_entry_set_text(GTK_ENTRY(entry_amount), "");
    gtk_entry_set_text(GTK_ENTRY(entry_vendor), "");
    gtk_entry_set_text(GTK_ENTRY(entry_city), "");
-#ifdef ENABLE_GTK2
-   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_attendees_buffer), "", -1);
-   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_note_buffer), "", -1);
-#else
-   gtk_text_backward_delete(GTK_TEXT(text_attendees),
-                            gtk_text_get_length(GTK_TEXT(text_attendees)));
-   gtk_text_backward_delete(GTK_TEXT(text_note),
-                            gtk_text_get_length(GTK_TEXT(text_note)));
-#endif
+   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(attendees_buffer), "", -1);
+   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(note_buffer), "", -1);
 
    set_new_button_to(CLEAR_FLAG);
 
@@ -700,10 +672,8 @@ static void cb_add_new_record(GtkWidget *widget, gpointer data)
    int flag;
    unsigned int unique_id = 0;
    struct MyExpense *mexp = NULL;
-#ifdef ENABLE_GTK2
    GtkTextIter start_iter;
    GtkTextIter end_iter;
-#endif
 
    jp_logf(JP_LOG_DEBUG, "Expense: cb_add_new_record\n");
 
@@ -758,25 +728,15 @@ static void cb_add_new_record(GtkWidget *widget, gpointer data)
    ex.date.tm_min  = 0;
    ex.date.tm_sec  = 0;
 
-#ifdef ENABLE_GTK2
-   gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(text_attendees_buffer),&start_iter,&end_iter);
-   ex.attendees = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_attendees_buffer),&start_iter,&end_iter,TRUE);
-#else
-   /* gtk_editable_get_chars *does* allocate memory */
-   ex.attendees = gtk_editable_get_chars(GTK_EDITABLE(text_attendees), 0, -1);
-#endif
+   gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(attendees_buffer),&start_iter,&end_iter);
+   ex.attendees = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(attendees_buffer),&start_iter,&end_iter,TRUE);
    if (ex.attendees[0]=='\0') {
       free(ex.attendees);
       ex.attendees=NULL;
    }
 
-#ifdef ENABLE_GTK2
-   gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(text_note_buffer),&start_iter,&end_iter);
-   ex.note = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(text_note_buffer),&start_iter,&end_iter,TRUE);
-#else
-   /* gtk_editable_get_chars *does* allocate memory */
-   ex.note = gtk_editable_get_chars(GTK_EDITABLE(text_note), 0, -1);
-#endif
+   gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(note_buffer),&start_iter,&end_iter);
+   ex.note = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(note_buffer),&start_iter,&end_iter,TRUE);
    if (ex.note[0]=='\0') {
       free(ex.note);
       ex.note=NULL;
@@ -1071,11 +1031,7 @@ static void cb_edit_cats(GtkWidget *widget, gpointer data)
    char full_name[256];
    char buffer[65536];
    int num;
-#ifdef PILOT_LINK_0_12
    size_t size;
-#else
-   int size;
-#endif
    void *buf;
    struct pi_file *pf;
 
@@ -1215,35 +1171,15 @@ static void cb_clist_selection(GtkWidget      *clist,
       gtk_entry_set_text(GTK_ENTRY(entry_city), "");
    }
    
-#ifdef ENABLE_GTK2
-   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_attendees_buffer), "", -1);
-#else
-   gtk_text_set_point(GTK_TEXT(text_attendees), 0);
-   gtk_text_forward_delete(GTK_TEXT(text_attendees),
-                           gtk_text_get_length(GTK_TEXT(text_attendees)));
-#endif
+   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(attendees_buffer), "", -1);
 
    if (mexp->ex.attendees) {
-#ifdef ENABLE_GTK2
-      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_attendees_buffer), mexp->ex.attendees, -1);
-#else
-      gtk_text_insert(GTK_TEXT(text_attendees), NULL,NULL,NULL, mexp->ex.attendees, -1);
-#endif
+      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(attendees_buffer), mexp->ex.attendees, -1);
    }
 
-#ifdef ENABLE_GTK2
-   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_note_buffer), "", -1);
-#else
-   gtk_text_set_point(GTK_TEXT(text_note), 0);
-   gtk_text_forward_delete(GTK_TEXT(text_note),
-                           gtk_text_get_length(GTK_TEXT(text_note)));
-#endif
+   gtk_text_buffer_set_text(GTK_TEXT_BUFFER(note_buffer), "", -1);
    if (mexp->ex.note) {
-#ifdef ENABLE_GTK2
-      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(text_note_buffer), mexp->ex.note, -1);
-#else
-      gtk_text_insert(GTK_TEXT(text_note), NULL,NULL,NULL, mexp->ex.note, -1);
-#endif
+      gtk_text_buffer_set_text(GTK_TEXT_BUFFER(note_buffer), mexp->ex.note, -1);
    }
 
    connect_changed_signals(CONNECT_SIGNALS);
@@ -1512,6 +1448,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    time_t ltime;
    struct tm *now;
    long ivalue;
+   int i;
    
    jp_logf(JP_LOG_DEBUG, "Expense: plugin gui started, unique_id=%d\n", unique_id);
 
@@ -1527,11 +1464,15 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
 
    /* Make the menus */
    jp_logf(JP_LOG_DEBUG, "Expense: calling make_menus\n");
+   for (i=0; i<MAX_CATEGORY2; i++) {
+      menu_item_category2[i] = NULL;
+   }
+
    make_menus();
 
    pane = gtk_hpaned_new();
    get_pref(PREF_EXPENSE_PANE, &ivalue, NULL);
-   gtk_paned_set_position(GTK_PANED(pane), ivalue + PANE_CREEP);
+   gtk_paned_set_position(GTK_PANED(pane), ivalue);
 
    gtk_box_pack_start(GTK_BOX(hbox), pane, TRUE, TRUE, 5);
 
@@ -1547,11 +1488,7 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /* Make accelerators for some buttons window */
 #ifndef ENABLE_STOCK_BUTTONS
    accel_group = gtk_accel_group_new();
-#ifdef ENABLE_GTK2
    gtk_window_add_accel_group(GTK_WINDOW(gtk_widget_get_toplevel(vbox)), accel_group);
-#else
-   gtk_accel_group_attach(accel_group, GTK_OBJECT(gtk_widget_get_toplevel(vbox)));
-#endif
 #endif
 
    /************************************************************/
@@ -1649,65 +1586,40 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /* Category Menu */
    label = gtk_label_new(_("Category:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 0, 1, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 0, 1);
-#endif
+                    0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 0);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(menu_category2),
                              1, 2, 0, 1);
 
    /* Type Menu */
    label = gtk_label_new(_("Type:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 1, 2, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 1, 2);
-#endif
+                    0, 1, 1, 2, GTK_FILL, GTK_FILL, 2, 0);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(menu_expense_type),
                              1, 2, 1, 2);
 
    /* Payment Menu */
    label = gtk_label_new(_("Payment:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 2, 3, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 2, 3);
-#endif
+                    0, 1, 2, 3, GTK_FILL, GTK_FILL, 2, 0);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(menu_payment),
                              1, 2, 2, 3);
 
    /* Currency Menu */
    label = gtk_label_new(_("Currency:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 3, 4, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 3, 4);
-#endif
+                    0, 1, 3, 4, GTK_FILL, GTK_FILL, 2, 0);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(menu_currency),
                              1, 2, 3, 4);
 
    /* Date Spinners */
    label = gtk_label_new(_("Date:"));
-   gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
+   gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.8);
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 4, 5, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 4, 5);
-#endif
+                    0, 1, 4, 5, GTK_FILL, GTK_FILL, 2, 0);
 
    hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(hbox_temp),
@@ -1759,13 +1671,8 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /* Amount Entry */
    label = gtk_label_new(_("Amount:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 5, 6, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 5, 6);
-#endif
+                    0, 1, 5, 6, GTK_FILL, GTK_FILL, 2, 0);
    entry_amount = gtk_entry_new();
    entry_set_multiline_truncate(GTK_ENTRY(entry_amount), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_amount),
@@ -1774,13 +1681,8 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /* Vendor Entry */
    label = gtk_label_new(_("Vendor:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 6, 7, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 6, 7);
-#endif
+                    0, 1, 6, 7, GTK_FILL, GTK_FILL, 2, 0);
    entry_vendor = gtk_entry_new();
    entry_set_multiline_truncate(GTK_ENTRY(entry_vendor), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_vendor),
@@ -1789,13 +1691,8 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
    /* City */
    label = gtk_label_new(_("City:"));
    gtk_misc_set_alignment(GTK_MISC(label), 1.0, 0.5);
-#ifdef ENABLE_GTK2
    gtk_table_attach(GTK_TABLE(table), GTK_WIDGET(label),
-                    0, 1, 7, 8, GTK_FILL, 0, 2, 0);
-#else
-   gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(label),
-                             0, 1, 7, 8);
-#endif
+                    0, 1, 7, 8, GTK_FILL, GTK_FILL, 2, 0);
    entry_city = gtk_entry_new();
    entry_set_multiline_truncate(GTK_ENTRY(entry_city), TRUE);
    gtk_table_attach_defaults(GTK_TABLE(table), GTK_WIDGET(entry_city),
@@ -1813,17 +1710,11 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_box_pack_start(GTK_BOX(vbox2), scrolled_window, TRUE, TRUE, 0);
 
-#ifdef ENABLE_GTK2
-   text_attendees = gtk_text_view_new();
-   text_attendees_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_attendees)));
-   gtk_text_view_set_editable(GTK_TEXT_VIEW(text_attendees), TRUE);
-   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text_attendees), GTK_WRAP_WORD);
-#else
-   text_attendees = gtk_text_new(NULL, NULL);
-   gtk_text_set_editable(GTK_TEXT(text_attendees), TRUE);
-   gtk_text_set_word_wrap(GTK_TEXT(text_attendees), TRUE);
-#endif
-   gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(text_attendees));
+   attendees = gtk_text_view_new();
+   attendees_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(attendees)));
+   gtk_text_view_set_editable(GTK_TEXT_VIEW(attendees), TRUE);
+   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(attendees), GTK_WRAP_WORD);
+   gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(attendees));
 
    label = gtk_label_new(_("Note"));
    gtk_box_pack_start(GTK_BOX(vbox2), label, FALSE, FALSE, 0);
@@ -1836,17 +1727,11 @@ int plugin_gui(GtkWidget *vbox, GtkWidget *hbox, unsigned int unique_id)
                                   GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_box_pack_start(GTK_BOX(vbox2), scrolled_window, TRUE, TRUE, 0);
 
-#ifdef ENABLE_GTK2
-   text_note = gtk_text_view_new();
-   text_note_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(text_note)));
-   gtk_text_view_set_editable(GTK_TEXT_VIEW(text_note), TRUE);
-   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(text_note), GTK_WRAP_WORD);
-#else
-   text_note = gtk_text_new(NULL, NULL);
-   gtk_text_set_editable(GTK_TEXT(text_note), TRUE);
-   gtk_text_set_word_wrap(GTK_TEXT(text_note), TRUE);
-#endif
-   gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(text_note));
+   note = gtk_text_view_new();
+   note_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(note)));
+   gtk_text_view_set_editable(GTK_TEXT_VIEW(note), TRUE);
+   gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(note), GTK_WRAP_WORD);
+   gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(note));
 
    gtk_widget_show_all(hbox);
    gtk_widget_show_all(vbox);
@@ -1888,20 +1773,15 @@ int plugin_gui_cleanup() {
 
    free_myexpense_list(&glob_myexpense_list);
 
-   /* Remove the accelerators */
+   if (pane) {
+      /* Remove the accelerators */
 #ifndef ENABLE_STOCK_BUTTONS
-#ifdef ENABLE_GTK2
-   gtk_window_remove_accel_group(GTK_WINDOW(gtk_widget_get_toplevel(pane)), accel_group);
-#else
-   gtk_accel_group_detach(accel_group, GTK_OBJECT(gtk_widget_get_toplevel(pane)));
-#endif
+      gtk_window_remove_accel_group(GTK_WINDOW(gtk_widget_get_toplevel(pane)), accel_group);
 #endif
 
-#ifdef ENABLE_GTK2
-   set_pref(PREF_EXPENSE_PANE, gtk_paned_get_position(GTK_PANED(pane)), NULL, TRUE);
-#else
-   set_pref(PREF_EXPENSE_PANE, GTK_PANED(pane)->handle_xpos, NULL, TRUE);
-#endif
+      set_pref(PREF_EXPENSE_PANE, gtk_paned_get_position(GTK_PANED(pane)), NULL, TRUE);
+      pane = NULL;
+   }
 
    return EXIT_SUCCESS;
 }
@@ -2054,11 +1934,11 @@ int plugin_help(char **text, int *width, int *height)
     */
    *text = strdup(
            /*-------------------------------------------*/
-           "Expense plugin for J-Pilot was written by\n"
-           "Judd Montgomery (c) 1999.\n"
-           "judd@jpilot.org\n"
-           "http://jpilot.org"
-           );
+           _("Expense plugin for J-Pilot was written by\n"
+             "Judd Montgomery (c) 1999.\n"
+             "judd@jpilot.org\n"
+             "http://jpilot.org"
+           ));
    *height = 0;
    *width = 0;
    
