@@ -1,4 +1,4 @@
-/* $Id: memo.c,v 1.38 2007-11-06 20:12:45 rikster5 Exp $ */
+/* $Id: memo.c,v 1.43 2008/08/26 03:26:53 rikster5 Exp $ */
 
 /*******************************************************************************
  * memo.c
@@ -20,24 +20,208 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <ctype.h>
-#include <pi-source.h>
-#include <pi-socket.h>
 #include <pi-memo.h>
 #include <pi-dlp.h>
+
 #include "memo.h"
+#include "i18n.h"
 #include "utils.h"
 #include "log.h"
 #include "prefs.h"
 #include "libplugin.h"
 #include "password.h"
 
-#define MEMO_EOF 7
+/********************************* Constants **********************************/
+
+/****************************** Prototypes ************************************/
+int memo_sort(MemoList **memol, int sort_order);
+
+/****************************** Main Code *************************************/
+void free_MemoList(MemoList **memo)
+{
+   MemoList *temp_memo, *temp_memo_next;
+
+   for (temp_memo = *memo; temp_memo; temp_memo=temp_memo_next) {
+      free_Memo(&(temp_memo->mmemo.memo));
+      temp_memo_next = temp_memo->next;
+      free(temp_memo);
+   }
+   *memo = NULL;
+}
+
+int get_memo_app_info(struct MemoAppInfo *ai)
+{
+   int num;
+   unsigned int rec_size;
+   unsigned char *buf;
+   char DBname[32];
+   long memo_version;
+
+   memset(ai, 0, sizeof(*ai));
+   /* Put at least one entry in there */
+   strcpy(ai->category.name[0], "Unfiled");
+
+   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
+
+   switch (memo_version) {
+    case 0:
+    default:
+      strcpy(DBname, "MemoDB");
+      break;
+    case 1:
+      strcpy(DBname, "MemosDB-PMem");
+      break;
+    case 2:
+      strcpy(DBname, "Memo32DB");
+      break;
+   }
+
+   jp_get_app_info(DBname, &buf, (int*)&rec_size);
+   num = unpack_MemoAppInfo(ai, buf, rec_size);
+   if (buf) {
+      free(buf);
+   }
+   if ((num<0) || (rec_size<=0)) {
+      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), DBname);
+      return EXIT_FAILURE;
+   }
+
+   return EXIT_SUCCESS;
+}
+
+int get_memos(MemoList **memo_list, int sort_order)
+{
+   return get_memos2(memo_list, sort_order, 1, 1, 1, CATEGORY_ALL);
+}
+
+/*
+ * sort_order: 0=descending, 1=ascending (memos are sorted if set in pdb file)
+ * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
+ */
+int get_memos2(MemoList **memo_list, int sort_order,
+ 	       int modified, int deleted, int privates, int category)
+{
+   GList *records;
+   GList *temp_list;
+   int recs_returned, num;
+   struct Memo memo;
+   MemoList *temp_memo_list;
+   long keep_modified, keep_deleted;
+   int keep_priv;
+   long char_set;
+   char *newtext;
+   long memo_version;
+   buf_rec *br;
+   pi_buffer_t *RecordBuffer;
+
+   jp_logf(JP_LOG_DEBUG, "get_memos2()\n");
+   if (modified==2) {
+      get_pref(PREF_SHOW_MODIFIED, &keep_modified, NULL);
+   } else {
+      keep_modified = modified;
+   }
+   if (deleted==2) {
+      get_pref(PREF_SHOW_DELETED, &keep_deleted, NULL);
+   } else {
+      keep_deleted = deleted;
+   }
+   if (privates==2) {
+      keep_priv = show_privates(GET_PRIVATES);
+   } else {
+      keep_priv = privates;
+   }
+   get_pref(PREF_CHAR_SET, &char_set, NULL);
+
+   *memo_list=NULL;
+   recs_returned = 0;
+
+   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
+
+   switch (memo_version) {
+    case 0:
+    default:
+      num = jp_read_DB_files("MemoDB", &records);
+      break;
+    case 1:
+      num = jp_read_DB_files("MemosDB-PMem", &records);
+      break;
+    case 2:
+      num = jp_read_DB_files("Memo32DB", &records);
+      break;
+   }
+   if (-1 == num)
+     return 0;
+
+   for (temp_list = records; temp_list; temp_list = temp_list->next) {
+      if (temp_list->data) {
+	 br=temp_list->data;
+      } else {
+	 continue;
+      }
+      if (!br->buf) {
+	 continue;
+      }
+
+      if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
+	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
+	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
+	 continue;
+      }
+      if ((keep_priv != SHOW_PRIVATES) &&
+	  (br->attrib & dlpRecAttrSecret)) {
+	 continue;
+      }
+
+      RecordBuffer = pi_buffer_new(br->size);
+      memcpy(RecordBuffer->data, br->buf, br->size);
+      RecordBuffer->used = br->size;
+
+      if (unpack_Memo(&memo, RecordBuffer, memo_v1) == -1) {
+	 pi_buffer_free(RecordBuffer);
+	 continue;
+      }
+      pi_buffer_free(RecordBuffer);
+
+      if ( ((br->attrib & 0x0F) != category) && category != CATEGORY_ALL) {
+	 continue;
+      }
+      if (memo.text) {
+         newtext = charset_p2newj(memo.text, -1, char_set);
+         if (newtext) {
+            free(memo.text);
+            memo.text = newtext;
+         }
+      }
+
+      temp_memo_list = malloc(sizeof(MemoList));
+      if (!temp_memo_list) {
+	 jp_logf(JP_LOG_WARN, "get_memos2(): %s\n", _("Out of memory"));
+	 break;
+      }
+      memcpy(&(temp_memo_list->mmemo.memo), &memo, sizeof(struct Memo));
+      temp_memo_list->app_type = MEMO;
+      temp_memo_list->mmemo.rt = br->rt;
+      temp_memo_list->mmemo.attrib = br->attrib;
+      temp_memo_list->mmemo.unique_id = br->unique_id;
+      temp_memo_list->next = *memo_list;
+      *memo_list = temp_memo_list;
+      recs_returned++;
+   }
+
+   jp_free_DB_records(&records);
+
+   memo_sort(memo_list, sort_order);
+
+   jp_logf(JP_LOG_DEBUG, "Leaving get_memos2()\n");
+
+   return recs_returned;
+}
 
 int memo_compare(const void *v1, const void *v2)
 {
@@ -80,12 +264,10 @@ int memo_sort(MemoList **memol, int sort_order)
    }
 
    /* Count the entries in the list */
-   for (count=0, temp_memol=*memol; temp_memol; temp_memol=temp_memol->next, count++) {
-      ;
-   }
+   for (count=0, temp_memol=*memol; temp_memol; temp_memol=temp_memol->next, count++) {}
 
-   if (count<2) {
-      /* We don't have to sort less than 2 items */
+   if (count<2) { 
+      /* No need to sort 0 or 1 items */
       return EXIT_SUCCESS;
    }
 
@@ -140,14 +322,8 @@ int memo_sort(MemoList **memol, int sort_order)
 int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
 		  unsigned int *unique_id)
 {
-#ifndef PILOT_LINK_0_12
-   unsigned char record[65536];
-   int rec_len;
-#else /* PILOT_LINK_0_12 */
    pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
    buf_rec br;
-   long ivalue;
    long char_set;
    long memo_version;
 
@@ -159,31 +335,16 @@ int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
 	 charset_j2p(memo->text, strlen(memo->text)+1, char_set);
       }
    }
-#ifndef PILOT_LINK_0_12
-   rec_len = pack_Memo(memo, record, 65535);
-   if (!rec_len) {
-      PRINT_FILE_LINE;
-      jp_logf(JP_LOG_WARN, "pack_Memo %s\n", _("error"));
-      return EXIT_FAILURE;
-   }
-#else /* PILOT_LINK_0_12 */
    RecordBuffer = pi_buffer_new(0);
    if (pack_Memo(memo, RecordBuffer, memo_v1) == -1) {
       PRINT_FILE_LINE;
       jp_logf(JP_LOG_WARN, "pack_Memo %s\n", _("error"));
       return EXIT_FAILURE;
    }
-#endif /* PILOT_LINK_0_12 */
    br.rt=rt;
    br.attrib = attrib;
-#ifndef PILOT_LINK_0_12
-   br.buf = record;
-   br.size = rec_len;
-#else /* PILOT_LINK_0_12 */
    br.buf = RecordBuffer->data;
    br.size = RecordBuffer->used;
-
-#endif /* PILOT_LINK_0_12 */
    /* Keep unique ID intact */
    if (unique_id) {
       br.unique_id = *unique_id;
@@ -191,214 +352,25 @@ int pc_memo_write(struct Memo *memo, PCRecType rt, unsigned char attrib,
       br.unique_id = 0;
    }
 
-   get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
-   if (ivalue) {
+   switch (memo_version) {
+    case 0:
+    default:
+      jp_pc_write("MemoDB", &br);
+      break;
+    case 1:
+      jp_pc_write("MemosDB-PMem", &br);
+      break;
+    case 2:
       jp_pc_write("Memo32DB", &br);
-   } else {
-      if (memo_version==1) {
-	 jp_pc_write("MemosDB-PMem", &br);
-      } else {
-	 jp_pc_write("MemoDB", &br);
-      }
+      break;
    }
+
    if (unique_id) {
       *unique_id = br.unique_id;
    }
 
-#ifdef PILOT_LINK_0_12
    pi_buffer_free(RecordBuffer);
-#endif
 
    return EXIT_SUCCESS;
 }
 
-void free_MemoList(MemoList **memo)
-{
-   MemoList *temp_memo, *temp_memo_next;
-
-   for (temp_memo = *memo; temp_memo; temp_memo=temp_memo_next) {
-      free_Memo(&(temp_memo->mmemo.memo));
-      temp_memo_next = temp_memo->next;
-      free(temp_memo);
-   }
-   *memo = NULL;
-}
-
-int get_memo_app_info(struct MemoAppInfo *ai)
-{
-   int num;
-   unsigned int rec_size;
-   unsigned char *buf;
-   long ivalue;
-   char DBname[32];
-   long memo_version;
-
-   memset(ai, 0, sizeof(*ai));
-   /* Put at least one entry in there */
-   strcpy(ai->category.name[0], "Unfiled");
-
-   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
-
-   get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
-   if (ivalue) {
-      strcpy(DBname, "Memo32DB");
-   } else {
-      if (memo_version==1) {
-	 strcpy(DBname, "MemosDB-PMem");
-      } else {
-	 strcpy(DBname, "MemoDB");
-      }
-   }
-   jp_get_app_info(DBname, &buf, (int*)&rec_size);
-   num = unpack_MemoAppInfo(ai, buf, rec_size);
-   if (buf) {
-      free(buf);
-   }
-   if ((num<0) || (rec_size<=0)) {
-      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), DBname);
-      return EXIT_FAILURE;
-   }
-
-   return EXIT_SUCCESS;
-}
-
-int get_memos(MemoList **memo_list, int sort_order)
-{
-   return get_memos2(memo_list, sort_order, 1, 1, 1, CATEGORY_ALL);
-}
-/*
- * sort_order: 0=descending, 1=ascending (memos are sorted if set in pdb file)
- * modified, deleted and private, 0 for no, 1 for yes, 2 for use prefs
- */
-int get_memos2(MemoList **memo_list, int sort_order,
- 	       int modified, int deleted, int privates, int category)
-{
-   GList *records;
-   GList *temp_list;
-   int recs_returned, i, num;
-   struct Memo memo;
-   MemoList *temp_memo_list;
-   long keep_modified, keep_deleted;
-   int keep_priv;
-   long char_set;
-   long ivalue, memo_version;
-   buf_rec *br;
-#ifdef PILOT_LINK_0_12
-   pi_buffer_t *RecordBuffer;
-#endif /* PILOT_LINK_0_12 */
-
-   jp_logf(JP_LOG_DEBUG, "get_memos2()\n");
-   if (modified==2) {
-      get_pref(PREF_SHOW_MODIFIED, &keep_modified, NULL);
-   } else {
-      keep_modified = modified;
-   }
-   if (deleted==2) {
-      get_pref(PREF_SHOW_DELETED, &keep_deleted, NULL);
-   } else {
-      keep_deleted = deleted;
-   }
-   if (privates==2) {
-      keep_priv = show_privates(GET_PRIVATES);
-   } else {
-      keep_priv = privates;
-   }
-
-   *memo_list=NULL;
-   recs_returned = 0;
-
-   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
-
-   get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
-   if (ivalue) {
-      num = jp_read_DB_files("Memo32DB", &records);
-      if (-1 == num)
-        return 0;
-   } else {
-      if (memo_version==1) {
-	 num = jp_read_DB_files("MemosDB-PMem", &records);
-      } else {
-	 num = jp_read_DB_files("MemoDB", &records);
-      }
-      if (-1 == num)
-        return 0;
-   }
-
-   for (i=0, temp_list = records; temp_list; temp_list = temp_list->next, i++) {
-      if (temp_list->data) {
-	 br=temp_list->data;
-      } else {
-	 continue;
-      }
-      if (!br->buf) {
-	 continue;
-      }
-
-      if ( ((br->rt==DELETED_PALM_REC)  && (!keep_deleted)) ||
-	   ((br->rt==DELETED_PC_REC)    && (!keep_deleted)) ||
-	   ((br->rt==MODIFIED_PALM_REC) && (!keep_modified)) ) {
-	 continue;
-      }
-      if ((keep_priv != SHOW_PRIVATES) &&
-	  (br->attrib & dlpRecAttrSecret)) {
-	 continue;
-      }
-
-#ifndef PILOT_LINK_0_12
-      /* JPA unpacking sets memo buffer */
-      num = unpack_Memo(&memo, br->buf, br->size);
-#else /* PILOT_LINK_0_12 */
-      RecordBuffer = pi_buffer_new(br->size);
-      memcpy(RecordBuffer->data, br->buf, br->size);
-      RecordBuffer->used = br->size;
-#endif /* PILOT_LINK_0_12 */
-
-#ifndef PILOT_LINK_0_12
-      if (num <= 0) {
-	 continue;
-      }
-#else /* PILOT_LINK_0_12 */
-      if (unpack_Memo(&memo, RecordBuffer, memo_v1) == -1) {
-	 pi_buffer_free(RecordBuffer);
-	 continue;
-      }
-      pi_buffer_free(RecordBuffer);
-#endif /* PILOT_LINK_0_12 */
-
-      if ( ((br->attrib & 0x0F) != category) && category != CATEGORY_ALL) {
-	 continue;
-      }
-      get_pref(PREF_CHAR_SET, &char_set, NULL);
-      if (memo.text) {
-	 /* JPA character set conversion may require a longer buffer */
-
-         char *newtext; /* new buffer */
-
-         newtext = charset_p2newj(memo.text, strlen(memo.text)+1, char_set);
-         free(memo.text);
-         memo.text = newtext;
-      }
-
-      temp_memo_list = malloc(sizeof(MemoList));
-      if (!temp_memo_list) {
-	 jp_logf(JP_LOG_WARN, "get_memos2(): %s\n", _("Out of memory"));
-	 break;
-      }
-      memcpy(&(temp_memo_list->mmemo.memo), &memo, sizeof(struct Memo));
-      temp_memo_list->app_type = MEMO;
-      temp_memo_list->mmemo.rt = br->rt;
-      temp_memo_list->mmemo.attrib = br->attrib;
-      temp_memo_list->mmemo.unique_id = br->unique_id;
-      temp_memo_list->next = *memo_list;
-      *memo_list = temp_memo_list;
-      recs_returned++;
-   }
-
-   jp_free_DB_records(&records);
-
-   memo_sort(memo_list, sort_order);
-
-   jp_logf(JP_LOG_DEBUG, "Leaving get_memos2()\n");
-
-   return recs_returned;
-}
