@@ -1,4 +1,4 @@
-/* $Id: memo_gui.c,v 1.115 2008/05/25 09:46:20 rousseau Exp $ */
+/* $Id: memo_gui.c,v 1.128 2008/10/30 15:07:12 rousseau Exp $ */
 
 /*******************************************************************************
  * memo_gui.c
@@ -20,34 +20,40 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include "i18n.h"
+#include <stdlib.h>
+#include <string.h>
+#include <time.h>
+#include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#include <time.h>
-#include <stdlib.h>
-#include <string.h>
 #include <pi-dlp.h>
+
+#include "memo.h"
+#include "i18n.h"
 #include "utils.h"
 #include "log.h"
 #include "prefs.h"
 #include "password.h"
 #include "print.h"
-#include "memo.h"
 #include "export.h"
 #include "stock_buttons.h"
 
+/********************************* Constants **********************************/
+#define NUM_MEMO_CAT_ITEMS 16
 
 #define MEMO_MAX_COLUMN_LEN 80
 #define MEMO_CLIST_CHAR_WIDTH 50
 
-#define NUM_MEMO_CAT_ITEMS 16
+#define NUM_MEMO_CSV_FIELDS 3
 
 #define CONNECT_SIGNALS 400
 #define DISCONNECT_SIGNALS 401
 
+/******************************* Global vars **********************************/
 /* Keeps track of whether code is using Memo, or Memos database
  * 0 is Memo, 1 is Memos */
 static long memo_version=0;
@@ -61,12 +67,10 @@ static int memo_category = CATEGORY_ALL;
 static int clist_row_selected;
 static GtkWidget *clist;
 static GtkWidget *memo_text;
-#ifdef ENABLE_GTK2
 static GObject   *memo_text_buffer;
-#endif
 static GtkWidget *private_checkbox;
-/*Need one extra for the ALL category */
-static GtkWidget *memo_cat_menu_item1[NUM_MEMO_CAT_ITEMS+1];
+/* Need two extra slots for the ALL category and Edit Categories... */
+static GtkWidget *memo_cat_menu_item1[NUM_MEMO_CAT_ITEMS+2];
 static GtkWidget *memo_cat_menu_item2[NUM_MEMO_CAT_ITEMS];
 static GtkWidget *category_menu1;
 static GtkWidget *category_menu2;
@@ -84,6 +88,7 @@ static int record_changed;
 static MemoList *glob_memo_list=NULL;
 static MemoList *export_memo_list=NULL;
 
+/****************************** Prototypes ************************************/
 static int memo_clear_details();
 int memo_clist_redraw();
 static void connect_changed_signals(int con_or_dis);
@@ -92,7 +97,9 @@ int memo_get_details(struct Memo *new_memo, unsigned char *attrib);
 static void memo_update_clist(GtkWidget *clist, GtkWidget *tooltip_widget,
 			      MemoList **memo_list, int category, int main);
 static void cb_add_new_record(GtkWidget *widget, gpointer data);
+static void cb_edit_cats(GtkWidget *widget, gpointer data);
 
+/****************************** Main Code *************************************/
 static void set_new_button_to(int new_state)
 {
    jp_logf(JP_LOG_DEBUG, "set_new_button_to new %d old %d\n", new_state, record_changed);
@@ -178,6 +185,7 @@ static void connect_changed_signals(int con_or_dis)
 {
    int i;
    static int connected=0;
+
    /* CONNECT */
    if ((con_or_dis==CONNECT_SIGNALS) && (!connected)) {
       connected=1;
@@ -188,13 +196,8 @@ static void connect_changed_signals(int con_or_dis)
 			       GTK_SIGNAL_FUNC(cb_record_changed), NULL);
 	 }
       }
-#ifdef ENABLE_GTK2
       g_signal_connect(memo_text_buffer, "changed",
 		       GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#else
-      gtk_signal_connect(GTK_OBJECT(memo_text), "changed",
-			 GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#endif
 
       gtk_signal_connect(GTK_OBJECT(private_checkbox), "toggled",
 			 GTK_SIGNAL_FUNC(cb_record_changed), NULL);
@@ -210,13 +213,8 @@ static void connect_changed_signals(int con_or_dis)
 					  GTK_SIGNAL_FUNC(cb_record_changed), NULL);
 	 }
       }
-#ifdef ENABLE_GTK2
       g_signal_handlers_disconnect_by_func(memo_text_buffer,
 					   GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#else
-      gtk_signal_disconnect_by_func(GTK_OBJECT(memo_text),
-				    GTK_SIGNAL_FUNC(cb_record_changed), NULL);
-#endif
       gtk_signal_disconnect_by_func(GTK_OBJECT(private_checkbox),
 				    GTK_SIGNAL_FUNC(cb_record_changed), NULL);
    }
@@ -311,11 +309,9 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
 	 strcat(text, line);
       }
 
-#ifdef ENABLE_GTK2
       /* convert to valid UTF-8 and recalculate the length */
       jp_charset_p2j(text, sizeof(text));
       text_len = strlen(text);
-#endif
 #ifdef JPILOT_DEBUG
       printf("text=[%s]\n", text);
       printf("text_len=%d\n", text_len);
@@ -327,7 +323,7 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
       ret=import_record_ask(parent_window, pane,
 			    new_memo.text,
 			    &(memo_app_info.category),
-			    "Unfiled",
+			    _("Unfiled"),
 			    0,
 			    attrib & 0x0F,
 			    &new_cat_num);
@@ -340,8 +336,10 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
    /* CSV */
    if (type==IMPORT_TYPE_CSV) {
       jp_logf(JP_LOG_DEBUG, "Memo import CSV [%s]\n", file_path);
-      /* Skip the first line which contains the format */
+      /* Get the first line containing the format and check for reasonableness */
       fgets(text, sizeof(text), in);
+      ret = verify_csv_header(text, NUM_MEMO_CSV_FIELDS, file_path);
+      if (EXIT_FAILURE == ret) return EXIT_FAILURE;
 
       import_all=FALSE;
       while (1) {
@@ -351,7 +349,7 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
 #ifdef JPILOT_DEBUG
 	 printf("category is [%s]\n", text);
 #endif
-	 g_strlcpy(old_cat_name, text, 17);
+	 g_strlcpy(old_cat_name, text, 16);
 	 /* Figure out what the best category number is */
 	 suggested_cat_num=0;
 	 for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
@@ -418,10 +416,10 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
 	 new_memo.text=temp_memolist->mmemo.memo.text;
 	 index=temp_memolist->mmemo.unique_id-1;
 	 if (index<0) {
-	    g_strlcpy(old_cat_name, _("Unfiled"), 17);
+	    g_strlcpy(old_cat_name, _("Unfiled"), 16);
 	    index=0;
 	 } else {
-	    g_strlcpy(old_cat_name, cai.name[index], 17);
+	    g_strlcpy(old_cat_name, cai.name[index], 16);
 	 }
 	 attrib=0;
 	 /* Figure out what category it was in the dat file */
@@ -470,9 +468,9 @@ int cb_memo_import(GtkWidget *parent_window, const char *file_path, int type)
 int memo_import(GtkWidget *window)
 {
    char *type_desc[] = {
-      "Text",
-      "CSV (Comma Separated Values)",
-      "DAT/MPA (Palm Archive Formats)",
+      N_("Text"),
+      N_("CSV (Comma Separated Values)"),
+      N_("DAT/MPA (Palm Archive Formats)"),
       NULL
    };
    int type_int[] = {
@@ -499,7 +497,6 @@ int memo_import(GtkWidget *window)
 /*
  * Start Export code
  */
-
 void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
 		       int type, const char *filename)
 {
@@ -517,7 +514,7 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
    char str1[256], str2[256];
    char date_string[1024];
    char pref_time[40];
-   char *csv_text;
+   char csv_text[65550];
    long char_set;
    char *utf;
 
@@ -592,18 +589,12 @@ void cb_memo_export_ok(GtkWidget *export_window, GtkWidget *clist,
 	    len=strlen(mmemo->memo.text) * 2 + 4;
 	 }
 	 if (len<256) len=256;
-	 csv_text=malloc(len);
-	 if (!csv_text) {
-	    continue;
-	    jp_logf(JP_LOG_WARN, _("Can't export memo %d\n"), (long) temp_list->data + 1);
-	 }
 	 utf = charset_p2newj(memo_app_info.category.name[mmemo->attrib & 0x0F], 16, char_set);
 	 fprintf(out, "\"%s\",", utf);
 	 g_free(utf);
 	 fprintf(out, "\"%s\",", (mmemo->attrib & dlpRecAttrSecret) ? "1":"0");
 	 str_to_csv_str(csv_text, mmemo->memo.text);
 	 fprintf(out, "\"%s\"\n", csv_text);
-	 free(csv_text);
 	 break;
 
        case EXPORT_TYPE_TEXT:
@@ -653,17 +644,15 @@ static void cb_memo_export_done(GtkWidget *widget, const char *filename)
 int memo_export(GtkWidget *window)
 {
    int w, h, x, y;
-   char *type_text[]={"Text", "CSV", NULL};
+   char *type_text[]={N_("Text"), 
+	                   N_("CSV"), 
+							 NULL};
    int type_int[]={EXPORT_TYPE_TEXT, EXPORT_TYPE_CSV};
 
    gdk_window_get_size(window->window, &w, &h);
    gdk_window_get_root_origin(window->window, &x, &y);
 
-#ifdef ENABLE_GTK2
    w = gtk_paned_get_position(GTK_PANED(pane));
-#else
-   w = GTK_PANED(pane)->handle_xpos;
-#endif
    x+=40;
 
    export_gui(window,
@@ -678,12 +667,10 @@ int memo_export(GtkWidget *window)
 
    return EXIT_SUCCESS;
 }
-
 /*
  * End Export Code
  */
 
-
 static int find_sorted_cat(int cat)
 {
    int i;
@@ -701,13 +688,13 @@ void cb_delete_memo(GtkWidget *widget,
    MyMemo *mmemo;
    int flag;
    int show_priv;
-   long char_set; /* JPA */
+   long char_set;
 
    mmemo = gtk_clist_get_row_data(GTK_CLIST(clist), clist_row_selected);
    if (mmemo < (MyMemo *)CLIST_MIN_DATA) {
       return;
    }
-   /* JPA convert to Palm character set */
+   /* Convert to Palm character set */
    get_pref(PREF_CHAR_SET, &char_set, NULL);
    if (char_set != CHAR_SET_LATIN1) {
       if (mmemo->memo.text)
@@ -786,6 +773,65 @@ static void cb_cancel(GtkWidget *widget, gpointer data)
    memo_refresh();
 }
 
+static void cb_edit_cats(GtkWidget *widget, gpointer data)
+{
+   struct MemoAppInfo ai;
+   char db_name[FILENAME_MAX];
+   char pdb_name[FILENAME_MAX];
+   char full_name[FILENAME_MAX];
+   unsigned char buffer[65536];
+   int num;
+   size_t size;
+   void *buf;
+   struct pi_file *pf;
+   long memo_version;
+     
+   jp_logf(JP_LOG_DEBUG, "cb_edit_cats\n");
+
+   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
+
+   switch (memo_version) {
+    case 0:
+    default:
+      strcpy(pdb_name, "MemoDB.pdb");
+      strcpy(db_name, "MemoDB");
+      break;
+    case 1:
+      strcpy(pdb_name, "MemosDB-PMem.pdb");
+      strcpy(db_name, "MemosDB-PMem");
+      break;
+    case 2:
+      strcpy(pdb_name, "Memo32DB.pdb");
+      strcpy(db_name, "Memo32DB");
+      break;
+   }
+
+   get_home_file_name(pdb_name, full_name, sizeof(full_name));
+
+   buf=NULL;
+   memset(&ai, 0, sizeof(ai));
+
+   pf = pi_file_open(full_name);
+   pi_file_get_app_info(pf, &buf, &size);
+
+   num = unpack_MemoAppInfo(&ai, buf, size);
+   if (num <= 0) {
+      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), pdb_name);
+      return;
+   }
+
+   pi_file_close(pf);
+
+   edit_cats(widget, db_name, &(ai.category));
+
+   size = pack_MemoAppInfo(&ai, buffer, sizeof(buffer));
+
+   pdb_file_write_app_block(db_name, buffer, size);
+   
+
+   cb_app_button(NULL, GINT_TO_POINTER(REDRAW));
+}
+
 static void cb_category(GtkWidget *item, int selection)
 {
    int b;
@@ -796,7 +842,11 @@ static void cb_category(GtkWidget *item, int selection)
 	 cb_add_new_record(NULL, GINT_TO_POINTER(record_changed));
       }
 
-      memo_category = selection;
+      if (selection==NUM_MEMO_CAT_ITEMS+1) {
+         cb_edit_cats(item, NULL);
+      } else {
+         memo_category = selection;
+      }
       clist_row_selected = 0;
       jp_logf(JP_LOG_DEBUG, "cb_category() cat=%d\n", memo_category);
       memo_clear_details();
@@ -812,20 +862,10 @@ static int memo_clear_details()
 
    jp_logf(JP_LOG_DEBUG, "memo_clear_details()\n");
 
-   /* Need to disconnect these signals first */
+   /* Need to disconnect signals first */
    connect_changed_signals(DISCONNECT_SIGNALS);
 
-#ifdef ENABLE_GTK2
    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(memo_text_buffer), "", -1);
-#else
-   gtk_text_freeze(GTK_TEXT(memo_text));
-
-   gtk_text_set_point(GTK_TEXT(memo_text), 0);
-   gtk_text_forward_delete(GTK_TEXT(memo_text),
-			   gtk_text_get_length(GTK_TEXT(memo_text)));
-
-   gtk_text_thaw(GTK_TEXT(memo_text));
-#endif
 
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(private_checkbox), FALSE);
 
@@ -853,22 +893,17 @@ static int memo_clear_details()
 int memo_get_details(struct Memo *new_memo, unsigned char *attrib)
 {
    int i;
-#ifdef ENABLE_GTK2
    GtkTextIter start_iter;
    GtkTextIter end_iter;
 
    gtk_text_buffer_get_bounds(GTK_TEXT_BUFFER(memo_text_buffer),&start_iter,&end_iter);
    new_memo->text = gtk_text_buffer_get_text(GTK_TEXT_BUFFER(memo_text_buffer),&start_iter,&end_iter,TRUE);
-#else
-   new_memo->text = gtk_editable_get_chars
-     (GTK_EDITABLE(memo_text), 0, -1);
-#endif
    if (new_memo->text[0]=='\0') {
       free(new_memo->text);
       new_memo->text=NULL;
    }
 
-   /*Get the category that is set from the menu */
+   /* Get the category that is set from the menu */
    for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
       if (GTK_IS_WIDGET(memo_cat_menu_item2[i])) {
 	 if (GTK_CHECK_MENU_ITEM(memo_cat_menu_item2[i])->active) {
@@ -911,7 +946,7 @@ static void cb_add_new_record(GtkWidget *widget, gpointer data)
    }
    /* End Masking */
    if (flag==CLEAR_FLAG) {
-      /*Clear button was hit */
+      /* Clear button was hit */
       memo_clear_details();
       connect_changed_signals(DISCONNECT_SIGNALS);
       set_new_button_to(NEW_FLAG);
@@ -975,72 +1010,6 @@ static void clear_mymemo(MyMemo *mmemo)
 }
 /* End Masking */
 
-
-#if 0
-static void cb_edit_cats(GtkWidget *widget, gpointer data)
-{
-   struct MemoAppInfo ai;
-   char db_name[FILENAME_MAX];
-   char pdb_name[FILENAME_MAX];
-   char full_name[FILENAME_MAX];
-   unsigned char buffer[65536];
-   int num;
-#ifdef PILOT_LINK_0_12
-   size_t size;
-#else
-   int size;
-#endif
-   void *buf;
-   long ivalue;
-   struct pi_file *pf;
-   long memo_version;
-     
-   jp_logf(JP_LOG_DEBUG, "cb_edit_cats\n");
-
-   get_pref(PREF_MEMO_VERSION, &memo_version, NULL);
-
-   get_pref(PREF_MEMO32_MODE, &ivalue, NULL);
-
-   if (ivalue) {
-      strcpy(pdb_name, "Memo32DB.pdb");
-      strcpy(db_name, "Memo32DB");
-   } else {
-      if (memo_version==1) {
-	 strcpy(pdb_name, "MemosDB-PMem.pdb");
-	 strcpy(db_name, "MemosDB-PMem");
-      } else {
-	 strcpy(pdb_name, "MemoDB.pdb");
-	 strcpy(db_name, "MemoDB");
-      }
-   }
-   get_home_file_name(pdb_name, full_name, sizeof(full_name));
-
-   buf=NULL;
-   memset(&ai, 0, sizeof(ai));
-
-   pf = pi_file_open(full_name);
-   pi_file_get_app_info(pf, &buf, &size);
-
-   num = unpack_MemoAppInfo(&ai, buf, size);
-   if (num <= 0) {
-      jp_logf(JP_LOG_WARN, _("Error reading file: %s\n"), pdb_name);
-      return;
-   }
-
-   pi_file_close(pf);
-
-   edit_cats(widget, db_name, &(ai.category));
-
-   size = pack_MemoAppInfo(&ai, buffer, sizeof(buffer));
-
-   pdb_file_write_app_block(db_name, buffer, size);
-   
-
-   cb_app_button(NULL, GINT_TO_POINTER(REDRAW));
-}
-#endif
-
-
 static void cb_clist_selection(GtkWidget      *clist,
 			       gint           row,
 			       gint           column,
@@ -1120,19 +1089,7 @@ static void cb_clist_selection(GtkWidget      *clist,
    }
    gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu2), count);
 
-#ifdef ENABLE_GTK2
    gtk_text_buffer_set_text(GTK_TEXT_BUFFER(memo_text_buffer), memo->text, -1);
-#else
-   gtk_text_freeze(GTK_TEXT(memo_text));
-
-   gtk_text_set_point(GTK_TEXT(memo_text), 0);
-   gtk_text_forward_delete(GTK_TEXT(memo_text),
-			   gtk_text_get_length(GTK_TEXT(memo_text)));
-
-   gtk_text_insert(GTK_TEXT(memo_text), NULL,NULL,NULL, memo->text, -1);
-
-   gtk_text_thaw(GTK_TEXT(memo_text));
-#endif
 
    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(private_checkbox),
 				mmemo->attrib & dlpRecAttrSecret);
@@ -1144,20 +1101,16 @@ static gboolean cb_key_pressed_left_side(GtkWidget   *widget,
                                          GdkEventKey *event,
                                          gpointer     next_widget)
 {
-#ifdef ENABLE_GTK2
    GtkTextBuffer *text_buffer;
    GtkTextIter    iter;
-#endif
 
    if (event->keyval == GDK_Return) {
       gtk_signal_emit_stop_by_name(GTK_OBJECT(widget), "key_press_event");
       gtk_widget_grab_focus(GTK_WIDGET(next_widget));
-#ifdef ENABLE_GTK2
       /* Position cursor at start of text */
       text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(next_widget));
       gtk_text_buffer_get_start_iter(text_buffer, &iter);
       gtk_text_buffer_place_cursor(text_buffer, &iter);
-#endif
       return TRUE;
    }
 
@@ -1358,7 +1311,6 @@ static int memo_find()
    return EXIT_SUCCESS;
 }
 
-/* This redraws the clist */
 int memo_clist_redraw()
 {
    memo_update_clist(clist, category_menu1, &glob_memo_list, memo_category, TRUE);
@@ -1413,7 +1365,15 @@ int memo_refresh()
    if (index<0) {
       jp_logf(JP_LOG_WARN, _("Category is not legal\n"));
    } else {
-      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index);
+      int i, index2 = 0;
+      for (i=0; i<NUM_MEMO_CAT_ITEMS; i++)
+      {
+	 if (memo_cat_menu_item1[i] && (memo_cat_menu_item1[i] != memo_cat_menu_item1[index]))
+	    index2++;
+	 if (memo_cat_menu_item1[i] == memo_cat_menu_item1[index])
+	    break;
+      }
+      gtk_option_menu_set_history(GTK_OPTION_MENU(category_menu1), index2);
       gtk_check_menu_item_set_active
 	(GTK_CHECK_MENU_ITEM(memo_cat_menu_item1[index]), TRUE);
    }
@@ -1431,11 +1391,7 @@ int memo_gui_cleanup()
    }
    free_MemoList(&glob_memo_list);
    connect_changed_signals(DISCONNECT_SIGNALS);
-#ifdef ENABLE_GTK2
    set_pref(PREF_MEMO_PANE, gtk_paned_get_position(GTK_PANED(pane)), NULL, TRUE);
-#else
-   set_pref(PREF_MEMO_PANE, GTK_PANED(pane)->handle_xpos, NULL, TRUE);
-#endif
    set_pref(PREF_LAST_MEMO_CATEGORY, memo_category, NULL, TRUE);
 
    return EXIT_SUCCESS;
@@ -1450,10 +1406,6 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
    GtkWidget *scrolled_window;
    GtkWidget *vbox1, *vbox2, *hbox_temp;
    GtkWidget *separator;
-   /*GtkWidget *button;*/
-#ifndef ENABLE_GTK2
-   GtkWidget *vscrollbar;
-#endif
    long ivalue;
    GtkAccelGroup *accel_group;
    long char_set;
@@ -1470,19 +1422,25 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
    }
 
    get_memo_app_info(&memo_app_info);
-
    get_pref(PREF_CHAR_SET, &char_set, NULL);
-   for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
+
+   for (i=1; i<NUM_MEMO_CAT_ITEMS; i++) {
       cat_name = charset_p2newj(memo_app_info.category.name[i], 31, char_set);
-      strcpy(sort_l[i].Pcat, cat_name);
+      strcpy(sort_l[i-1].Pcat, cat_name);
       free(cat_name);
-      sort_l[i].cat_num = i;
+      sort_l[i-1].cat_num = i;
    }
-   qsort(sort_l, NUM_MEMO_CAT_ITEMS, sizeof(struct sorted_cats), cat_compare);
+   /* put reserved 'Unfiled' category at end of list */ 
+   cat_name = charset_p2newj(memo_app_info.category.name[0], 31, char_set);
+   strcpy(sort_l[NUM_MEMO_CAT_ITEMS-1].Pcat, cat_name);
+   free(cat_name);
+   sort_l[NUM_MEMO_CAT_ITEMS-1].cat_num = 0;
+
+   qsort(sort_l, NUM_MEMO_CAT_ITEMS-1, sizeof(struct sorted_cats), cat_compare);
 
 #ifdef JPILOT_DEBUG
    for (i=0; i<NUM_MEMO_CAT_ITEMS; i++) {
-      printf("cat %d %s\n", sort_l[i].cat_num, sort_l[i].Pcat);
+      printf("cat %d [%s]\n", sort_l[i].cat_num, sort_l[i].Pcat);
    }
 #endif
 
@@ -1499,7 +1457,7 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 
    pane = gtk_hpaned_new();
    get_pref(PREF_MEMO_PANE, &ivalue, NULL);
-   gtk_paned_set_position(GTK_PANED(pane), ivalue + PANE_CREEP);
+   gtk_paned_set_position(GTK_PANED(pane), ivalue);
 
    gtk_box_pack_start(GTK_BOX(hbox), pane, TRUE, TRUE, 5);
 
@@ -1509,73 +1467,51 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
    gtk_paned_pack1(GTK_PANED(pane), vbox1, TRUE, FALSE);
    gtk_paned_pack2(GTK_PANED(pane), vbox2, TRUE, FALSE);
 
-   /* gtk_widget_set_usize(GTK_WIDGET(vbox1), 210, 0); */
-
    /* Add buttons in left vbox */
    /* Separator */
    separator = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(vbox1), separator, FALSE, FALSE, 5);
 
-   /* Make the Today is: label */
+   /* 'Today is:' label */
    glob_date_label = gtk_label_new(" ");
    gtk_box_pack_start(GTK_BOX(vbox1), glob_date_label, FALSE, FALSE, 0);
    timeout_date(NULL);
    glob_date_timer_tag = gtk_timeout_add(get_timeout_interval(), timeout_date, NULL);
 
-
    /* Separator */
    separator = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(vbox1), separator, FALSE, FALSE, 5);
 
-
-   /* Category Box */
+   /* Left-side Category menu */
    hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox1), hbox_temp, FALSE, FALSE, 0);
 
-   /* Put the left-hand category menu up */
    make_category_menu(&category_menu1, memo_cat_menu_item1,
-		      sort_l, cb_category, TRUE);
+		      sort_l, cb_category, TRUE, TRUE);
    gtk_box_pack_start(GTK_BOX(hbox_temp), category_menu1, TRUE, TRUE, 0);
 
-
-   /* Edit category button */
-	/* RW:5/8/2008: Temporarily removed ability to edit categories with Jpilot
-	 * because the back-end code WILL often lose user data */
-	/*
-   button = gtk_button_new_with_label(_("Edit Categories"));
-   gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		      GTK_SIGNAL_FUNC(cb_edit_cats), NULL);
-   gtk_box_pack_start(GTK_BOX(hbox_temp), button, FALSE, FALSE, 0);
-   */
-   /* Put the memo list window up */
+   /* Memo list scrolled window */
    scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-   /*gtk_widget_set_usize(GTK_WIDGET(scrolled_window), 330, 100); */
    gtk_container_set_border_width(GTK_CONTAINER(scrolled_window), 0);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolled_window),
 				  GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
    gtk_box_pack_start(GTK_BOX(vbox1), scrolled_window, TRUE, TRUE, 0);
 
    clist = gtk_clist_new(1);
-
-   gtk_signal_connect(GTK_OBJECT(clist), "select_row",
-		      GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
-
    gtk_clist_set_shadow_type(GTK_CLIST(clist), SHADOW);
    gtk_clist_set_selection_mode(GTK_CLIST(clist), GTK_SELECTION_BROWSE);
    gtk_clist_set_column_width(GTK_CLIST(clist), 0, 50);
 
+   gtk_signal_connect(GTK_OBJECT(clist), "select_row",
+		      GTK_SIGNAL_FUNC(cb_clist_selection), NULL);
+
    gtk_container_add(GTK_CONTAINER(scrolled_window), GTK_WIDGET(clist));
 
-   /*
-    * The right hand part of the main window follows:
-    */
+   /* The right hand part of the main window follows: */
    hbox_temp = gtk_hbox_new(FALSE, 3);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
 
-
-   /* Add record modification buttons on right side */
-
-   /* Create Cancel button */
+   /* Cancel button */
    CREATE_BUTTON(cancel_record_button, _("Cancel"), CANCEL, _("Cancel the modifications"), GDK_Escape, 0, "ESC")
    gtk_signal_connect(GTK_OBJECT(cancel_record_button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_cancel), NULL);
@@ -1592,19 +1528,19 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 		      GTK_SIGNAL_FUNC(cb_undelete_memo),
 		      GINT_TO_POINTER(UNDELETE_FLAG));
 
-   /* Create "Copy" button */
+   /* Copy button */
    CREATE_BUTTON(copy_record_button, _("Copy"), COPY, _("Copy the selected record"), GDK_o, GDK_CONTROL_MASK, "Ctrl+O")
    gtk_signal_connect(GTK_OBJECT(copy_record_button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_add_new_record),
 		      GINT_TO_POINTER(COPY_FLAG));
 
-   /* Create "New" button */
+   /* New button */
    CREATE_BUTTON(new_record_button, _("New Record"), NEW, _("Add a new record"), GDK_n, GDK_CONTROL_MASK, "Ctrl+N")
    gtk_signal_connect(GTK_OBJECT(new_record_button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_add_new_record),
 		      GINT_TO_POINTER(CLEAR_FLAG));
 
-   /* Create "Add Record" button */
+   /* "Add Record" button */
    CREATE_BUTTON(add_record_button, _("Add Record"), ADD, _("Add the new record"), GDK_Return, GDK_CONTROL_MASK, "Ctrl+Enter")
    gtk_signal_connect(GTK_OBJECT(add_record_button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_add_new_record),
@@ -1614,7 +1550,7 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 		       "label_high");
 #endif
 
-   /* Create "apply changes" button */
+   /* "Apply Changes" button */
    CREATE_BUTTON(apply_record_button, _("Apply Changes"), APPLY, _("Commit the modifications"), GDK_Return, GDK_CONTROL_MASK, "Ctrl+Enter")
    gtk_signal_connect(GTK_OBJECT(apply_record_button), "clicked",
 		      GTK_SIGNAL_FUNC(cb_add_new_record),
@@ -1625,33 +1561,28 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
 #endif
 
 
-   /*Separator */
+   /* Separator */
    separator = gtk_hseparator_new();
    gtk_box_pack_start(GTK_BOX(vbox2), separator, FALSE, FALSE, 5);
 
-
-   /*Private check box */
+   /* Private check box */
    hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
    private_checkbox = gtk_check_button_new_with_label(_("Private"));
    gtk_box_pack_end(GTK_BOX(hbox_temp), private_checkbox, FALSE, FALSE, 0);
 
-
-   /*Put the right-hand category menu up */
+   /* Put the right-hand category menu up */
    make_category_menu(&category_menu2, memo_cat_menu_item2,
-		      sort_l, NULL, FALSE);
+		      sort_l, NULL, FALSE, FALSE);
    gtk_box_pack_start(GTK_BOX(hbox_temp), category_menu2, TRUE, TRUE, 0);
 
-
-   /*The Description text box on the right side */
+   /* Description text box on the right side */
    hbox_temp = gtk_hbox_new(FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, FALSE, FALSE, 0);
 
-
    hbox_temp = gtk_hbox_new (FALSE, 0);
    gtk_box_pack_start(GTK_BOX(vbox2), hbox_temp, TRUE, TRUE, 0);
 
-#ifdef ENABLE_GTK2
    memo_text = gtk_text_view_new();
    memo_text_buffer = G_OBJECT(gtk_text_view_get_buffer(GTK_TEXT_VIEW(memo_text)));
    gtk_text_view_set_editable(GTK_TEXT_VIEW(memo_text), TRUE);
@@ -1663,14 +1594,6 @@ int memo_gui(GtkWidget *vbox, GtkWidget *hbox)
    gtk_container_set_border_width(GTK_CONTAINER(scrolled_window), 1);
    gtk_container_add(GTK_CONTAINER(scrolled_window), memo_text);
    gtk_box_pack_start_defaults(GTK_BOX(hbox_temp), scrolled_window);
-#else
-   memo_text = gtk_text_new(NULL, NULL);
-   gtk_text_set_editable(GTK_TEXT(memo_text), TRUE);
-   gtk_text_set_word_wrap(GTK_TEXT(memo_text), TRUE);
-   vscrollbar = gtk_vscrollbar_new(GTK_TEXT(memo_text)->vadj);
-   gtk_box_pack_start(GTK_BOX(hbox_temp), memo_text, TRUE, TRUE, 0);
-   gtk_box_pack_start(GTK_BOX(hbox_temp), vscrollbar, FALSE, FALSE, 0);
-#endif
 
    /* Capture the Enter & Shift-Enter key combinations to move back and 
     * forth between the left- and right-hand sides of the display. */
