@@ -1,4 +1,4 @@
-/* $Id: otherconv.c,v 1.29 2008/05/06 00:11:52 rikster5 Exp $ */
+/* $Id: otherconv.c,v 1.34 2008/09/03 10:07:43 rousseau Exp $ */
 
 /*******************************************************************************
  * otherconv.c
@@ -27,44 +27,45 @@
  * Unix : UTF-8
  */
 
+/********************************* Includes ***********************************/
 #include "config.h"
-#include <string.h>
-
-#ifdef ENABLE_GTK2
-#include <stdio.h>
-#include <errno.h>
 #include <stdlib.h>
+#include <stdio.h>
+#include <string.h>
+#include <errno.h>
 #include <glib.h>
-/* To speed up compilation use these instead of glib.h
-#include <glib/gmacros.h>
-#include <glib/gconvert.h>
-*/
-#include "prefs.h"
+
 #include "otherconv.h"
+#include "prefs.h"
 #include "log.h"
 
-static GIConv glob_topda = NULL;
-static GIConv glob_frompda = NULL;
-
+/********************************* Constants **********************************/
 #define HOST_CS "UTF-8"
 
+#define min(a,b) (((a) < (b)) ? (a) : (b))
+
 /* You can't do #ifndef __FUNCTION__ */
 #if !defined(__GNUC__) && !defined(__IBMC__)
 #define __FUNCTION__ ""
 #endif
 
+#define OC_FREE_ICONV(conv) oc_free_iconv(__FUNCTION__, conv,#conv)
 
+#define OTHERCONV_DEBUG
+
+/******************************* Global vars **********************************/
+static GIConv glob_topda = NULL;
+static GIConv glob_frompda = NULL;
+
+/****************************** Main Code *************************************/
 /*
  * strnlen is not ANSI.
- * To avoid messing with conflicting declarations, I just implement my own version.
- * (this is easy & portable might not be very efficient) -- Amit Aronovitch
+ * To avoid conflicting declarations, it is reimplemented as a thin
+ * inline function over the library function strlen
  */
-size_t oc_strnlen(const char *s, size_t maxlen) {
-  const char *p,*endp;
-
-  endp = s+maxlen;
-  for (p=s;p<endp;++p) if (! *p) break;
-  return p-s;
+size_t oc_strnlen(const char *s, size_t maxlen);
+inline size_t oc_strnlen(const char *s, size_t maxlen) {
+  return min(strlen(s), maxlen); 
 }
 
 void oc_free_iconv(const char *funcname, GIConv conv, char *convname) {
@@ -76,8 +77,6 @@ void oc_free_iconv(const char *funcname, GIConv conv, char *convname) {
   }
 }
 
-#define OC_FREE_ICONV(conv) oc_free_iconv(__FUNCTION__, conv,#conv)
-
 /*
  * Convert char_set integer code to iconv charset text string
  */
@@ -169,6 +168,7 @@ char *other_to_UTF(const char *buf, int buf_len)
   char *outbuf;
   gsize bytes_read;
   GError *err = NULL;
+  size_t str_len;
 
 #ifdef OTHERCONV_DEBUG
   jp_logf(JP_LOG_DEBUG, "%s:%s reset iconv state...\n", __FILE__, __FUNCTION__);
@@ -178,16 +178,22 @@ char *other_to_UTF(const char *buf, int buf_len)
   jp_logf(JP_LOG_DEBUG, "%s:%s converting   [%s]\n", __FILE__, __FUNCTION__, buf);
 #endif
 
+  if (buf_len == -1) {
+     str_len = -1;
+  } else {
+     str_len = oc_strnlen(buf, buf_len-1);  // -1 leaves room for \0 terminator
+  }
+
   outbuf = (char *)g_convert_with_iconv((gchar *)buf,
-      oc_strnlen(buf, buf_len) +1, /* see Debian bug #309082 for the +1 */
-      glob_frompda, &bytes_read, NULL, &err);
-  if (err != NULL || bytes_read < oc_strnlen (buf, buf_len)) {
+           str_len, glob_frompda, &bytes_read, NULL, &err);
+
+  if (err != NULL) {
       char c;
       char *head, *tail;
-      int outbuf_len;
+      int  outbuf_len;
       char *tmp_buf = (char *)buf;
       static int call_depth = 0;
-
+      printf("ERROR HAPPENED\n");
       if (0 == call_depth)
 	 jp_logf(JP_LOG_WARN, "%s:%s g_convert_with_iconv error: %s, buff: %s\n",
 	    __FILE__, __FUNCTION__, err ? err->message : "last char truncated",
@@ -197,6 +203,10 @@ char *other_to_UTF(const char *buf, int buf_len)
       else
 	 g_free(outbuf);
 
+      if (buf_len == -1) {
+         buf_len = strlen(buf); 
+      }
+
       /* convert the head, skip the problematic char, convert the tail */
       c = tmp_buf[bytes_read];
       tmp_buf[bytes_read] = '\0';
@@ -242,7 +252,8 @@ void UTF_to_other(char *const buf, int buf_len)
   gchar *inptr, *outptr;
   size_t rc;
   char *errstr;
-  char buf_out[1000], *buf_out_ptr = NULL;
+  char buf_out[1000];
+  char *buf_out_ptr = NULL;
 
 #ifdef OTHERCONV_DEBUG
   jp_logf(JP_LOG_DEBUG, "%s:%s reset iconv state...\n", __FILE__, __FUNCTION__);
@@ -252,25 +263,25 @@ void UTF_to_other(char *const buf, int buf_len)
   jp_logf(JP_LOG_DEBUG, "%s:%s converting   [%s]\n", __FILE__, __FUNCTION__, buf);
 #endif
 
-  inleft = oc_strnlen(buf,buf_len);
+  inleft = oc_strnlen(buf, buf_len);
   outleft = buf_len-1;
   inptr = buf;
 
-   if (buf_len > sizeof(buf_out))
-   {
-      buf_out_ptr = malloc(buf_len);
-      if (NULL == buf_out_ptr)
-      {
-	 jp_logf(JP_LOG_WARN, "no more memory");
-	 return;
-      }
-      outptr = buf_out_ptr;
-   }
-   else
-      outptr = buf_out;
+  /* Most strings can be converted without recourse to malloc */
+  if (buf_len > sizeof(buf_out)) {
+     buf_out_ptr = malloc(buf_len);
+     if (NULL == buf_out_ptr) {
+        jp_logf(JP_LOG_WARN, "UTF_to_other: %s\n", "Out of memory");
+        return;
+     }
+     outptr = buf_out_ptr;
+  } else {
+     outptr = buf_out;
+  }
 
   rc = g_iconv(glob_topda, &inptr, &inleft, &outptr, &outleft);
-  *outptr = 0;
+  *outptr = 0; /* NULL terminate whatever fraction was converted */
+
   if ((size_t)(-1) == rc) {
     switch (errno) {
     case EILSEQ:
@@ -288,29 +299,15 @@ void UTF_to_other(char *const buf, int buf_len)
     jp_logf(JP_LOG_WARN, errstr, inptr - buf);
   }
 
-   if (buf_out_ptr)
-   {
+   if (buf_out_ptr) {
       g_strlcpy(buf, buf_out_ptr, buf_len);
       free(buf_out_ptr);
-   }
-   else
+   } else {
       g_strlcpy(buf, buf_out, buf_len);
+   }
 
 #ifdef OTHERCONV_DEBUG
   jp_logf(JP_LOG_DEBUG, "%s:%s converted to [%s]\n", __FILE__, __FUNCTION__, buf);
 #endif
 }
 
-#else
-
-char *other_to_UTF(const char *buf, int buf_len)
-{
-	return strdup(buf);
-}
-
-void UTF_to_other(char *const buf, int buf_len)
-{
-}
-
-#endif
-
