@@ -1,4 +1,7 @@
-/* print_headers.c
+/* $Id: print_headers.c,v 1.8 2008/06/19 04:12:07 rikster5 Exp $ */
+
+/*******************************************************************************
+ * print_headers.c
  * A module of J-Pilot http://jpilot.org
  *
  * Copyright (C) 2001 by Colin Brough
@@ -16,14 +19,16 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- */
+ ******************************************************************************/
 
+/********************************* Includes ***********************************/
 #include <stdio.h>
 #include <string.h>
 
-void print_common_header(FILE *f)
+/****************************** Main Code *************************************/
+void print_common_prolog(FILE *f)
 {
-         char *common_header =
+   char *common_prolog =
         "/Recode {\n"
         "  exch\n"
         "  findfont\n"
@@ -35,17 +40,13 @@ void print_common_header(FILE *f)
         "  end\n"
         "  definefont pop\n"
         "} bind def\n\n"
-        "/Times-Roman      /Times-Roman-ISOLatin1 Recode\n"
-        "/Times-Bold       /Times-Bold-ISOLatin1 Recode\n"
-        "/Courier          /Courier-ISOLatin1 Recode\n"
-        "/Courier-Bold     /Courier-Bold-ISOLatin1 Recode\n"
-        "/Helvetica        /Helvetica-ISOLatin1 Recode\n"
-        "/edef   { exch def } def\n"
-        "/esub   { exch sub } def\n"
-        "/l      { lineto } def\n"
-        "/m      { moveto } def\n"
-        "/rm     { rmoveto } def\n"
-        "/rl { rlineto } def\n"
+	"/inch {72 mul} def\n"
+        "/edef { exch def } def\n"
+        "/esub { exch sub } def\n"
+        "/l    { lineto } def\n"
+        "/m    { moveto } def\n"
+        "/rm   { rmoveto } def\n"
+        "/rl   { rlineto } def\n"
         "/strw { stringwidth } def\n"
         "/nstr 10 string def\n"
         "/slw  { setlinewidth } def\n"
@@ -127,7 +128,19 @@ void print_common_header(FILE *f)
         "        [ (DL)           312     624 10 ]\n"
         "        [ (Filo)         270     487 12 ]\n"
         "] def\n"
-        "\n"
+        "\n";
+    fputs(common_prolog, f);
+}
+
+void print_common_setup(FILE *f)
+{
+   char *common_setup =
+        "%------------------------------------------------------------------\n"
+        "/Times-Roman      /Times-Roman-ISOLatin1 Recode\n"
+        "/Times-Bold       /Times-Bold-ISOLatin1 Recode\n"
+        "/Courier          /Courier-ISOLatin1 Recode\n"
+        "/Courier-Bold     /Courier-Bold-ISOLatin1 Recode\n"
+        "/Helvetica        /Helvetica-ISOLatin1 Recode\n"
         "%------------------------------------------------------------------\n"
         "% Based on the paper size, work out the scaling and fontsize for\n"
         "% the page.\n"
@@ -141,7 +154,7 @@ void print_common_header(FILE *f)
         "                /linespacing fontsize 1.1 mul def\n"
         "        } if\n"
         "} forall\n";
-    fputs(common_header, f);
+    fputs(common_setup, f);
 }
 
 /*----------------------------------------------------------------------
@@ -443,7 +456,6 @@ void print_week_header(FILE *f)
         "\n"
         "%-------------------------------------------------------------\n\n\n";
 
-    print_common_header(f);
     fputs(week_header, f);
 }
 
@@ -573,6 +585,83 @@ void print_month_header(FILE *f)
         "} def\n"
         "\n"
         "%------------------------------------------------------------------\n"
+        "% 'spacify' routine to replace line-feeds with spaces in strings\n"
+        "%  passed in - places string back on stack where it came from.\n"
+        "\n"
+        "/spacify {\n"
+        "        /LF 10 def\n"
+        "        /SP 32 def\n"
+        "\n"
+        "        /String edef\n"
+        "\n"
+        "        0 1 String length 1 sub {\n"
+        "                /I edef\n"
+        "                String I get LF eq {\n"
+        "                        String I SP put\n"
+        "                } if\n"
+        "        } for\n"
+        "        String\n"
+        "} def\n"
+        "\n"
+        "%------------------------------------------------------------------\n"
+        "% Move onto the next line\n"
+        "\n"
+        "/incY { /X X_LM def /Y Y fsize sub def } def\n"
+        "\n"
+        "%------------------------------------------------------------------\n"
+        "% This routine will do automatic line-breaking of the item text, so\n"
+        "% that as much of it as possible is visible.\n"
+        "%\n"
+        "% Arguments are: 'Paragraph Y para'\n"
+        "\n"
+        "/para {\n"
+        "    /RMpara X PrintBoxWidth add def\n"
+        "    /LMpara X def\n"
+        "    /Y edef\n"
+        "    spacify\n"
+        "    /Paragraph edef\n"
+        "    /SpaceW ( ) stringwidth pop def\n"
+        "    RMpara LMpara sub Paragraph stringwidth pop gt\n"
+        "    {\n"
+        "        %----------------------------------------------\n"
+        "        % The whole paragraph fits on one line - so\n"
+        "        % just print it!\n"
+        "        %----------------------------------------------\n"
+        "        LMpara Y m Paragraph show\n"
+        "    } {\n"
+        "        %----------------------------------------------\n"
+        "        % Have to do our clever formatting\n"
+        "        %----------------------------------------------\n"
+        "        /X LMpara def\n"
+        "        /I 0 def\n"
+        "        {\n"
+        "            Paragraph ( ) search\n"
+        "            {\n"
+        "                %--------------------------------------------\n"
+        "                % Found a space - so check where to print it.\n"
+        "                %--------------------------------------------\n"
+        "                dup\n"
+        "                stringwidth pop /SW edef\n"
+        "                SW RMpara X sub gt { /I I 1 add def I 2 eq { exit } if incY } if\n"
+        "                X Y m show\n"
+        "                pop\n"
+        "                /X X SW SpaceW add add def\n"
+        "                /Paragraph edef\n"
+        "            } {\n"
+        "                %----------------------------------------\n"
+        "                % No space. Print rest of string and exit\n"
+        "                %----------------------------------------\n"
+        "                RMpara X sub Paragraph stringwidth pop lt\n"
+        "                { /I I 1 add def I 2 eq { exit } if incY } if\n"
+        "                X Y m Paragraph show\n"
+        "                pop\n"
+        "                exit\n"
+        "            } ifelse\n"
+        "        } loop\n"
+        "    } ifelse\n"
+        "} def\n"
+        "\n"
+        "%------------------------------------------------------------------\n"
         "% This procedure prints an item\n"
         "\n"
         "/TimedItem {\n"
@@ -581,15 +670,23 @@ void print_month_header(FILE *f)
         "        /Helvetica-Oblique findfont fsize scalefont setfont\n"
         "        X Y m show\n"
         "        /Helvetica-ISOLatin1 findfont fsize scalefont setfont\n"
-        "        X 4.2 fsize mul add Y m ApptText show\n"
-        "        /Y Y fsize sub def\n"
+        "        /X_LM X def\n"
+        "        /X X 4.2 fsize mul add def\n"
+        "        /PrintBoxWidth BoxWidth X X_LM sub sub 3 sub def\n"
+        "        ApptText Y para\n"
+        "        incY\n"
         "} def\n"
         "\n"
         "/UntimedItem {\n"
         "        /ApptText edef\n"
         "        /Helvetica-ISOLatin1 findfont fsize scalefont setfont\n"
-        "        X 3 fsize mul add Y m ApptText show\n"
-        "        /Y Y fsize sub def\n"
+        "        /X_LM_save X def\n"
+	"        /X X 3 fsize mul add def\n"
+        "        /X_LM X def\n"
+        "        /PrintBoxWidth BoxWidth X X_LM_save sub sub 3 sub def\n"
+        "        ApptText Y para\n"
+	"        /X_LM X_LM_save def\n"
+	"        incY\n"
         "} def\n"
         "\n"
         "%------------------------------------------------------------------\n"
@@ -666,7 +763,6 @@ void print_month_header(FILE *f)
         "%------------------------------------------------------------------\n"
         "\n";
 
-    print_common_header(f);
     fputs(month_header, f);
 }
 
@@ -679,8 +775,8 @@ void print_day_header(FILE *f)
 {
     char *day_header =
         "ScaleY ScaleX Min dup scale\n"
-        "%%----------------------------------------\n"
-        "%% First the gray background area\n"
+        "%----------------------------------------\n"
+        "% First the gray background area\n"
         "newpath\n"
         "0 slw\n"
         " 0.5  inch  3.5 inch m\n"
@@ -694,8 +790,8 @@ void print_day_header(FILE *f)
         "-3    inch  0        rl\n"
         " 0         -6   inch rl\n"
         "closepath 0.85 setgray fill stroke\n"
-        "%%----------------------------------------\n"
-        "%% Next highlighting lines round title\n"
+        "%----------------------------------------\n"
+        "% Next highlighting lines round title\n"
         "0 setgray\n"
         "1 slw newpath 0.5 inch 10.5    inch m 7.5 inch 0 rl stroke\n"
         "      newpath 0.5 inch  9.5625 inch m 7.5 inch 0 rl stroke\n"
@@ -704,14 +800,14 @@ void print_day_header(FILE *f)
         "0 slw\n"
         "0 1 11 {\n"
         "	/I edef\n"
-        "	%%----------------------------------------\n"
-        "	%% The hours\n"
+        "	%----------------------------------------\n"
+        "	% The hours\n"
         "	0.5 inch 9.15 inch I 0.5 inch mul sub m\n"
         "	I 10 lt { (0) show } if I nstr cvs show (:00) show\n"
         "	4.25 inch 9.15 inch I 0.5 inch mul sub m\n"
         "	I 12 add nstr cvs show (:00) show\n"
-        "	%%----------------------------------------\n"
-        "	%% The horizontal lines between hours\n"
+        "	%----------------------------------------\n"
+        "	% The horizontal lines between hours\n"
         "	1.25 inch 9 inch I 0.5 inch mul sub m 3 inch 0 rl\n"
         "	5    inch 9 inch I 0.5 inch mul sub m 3 inch 0 rl\n"
         "} for\n"
@@ -800,4 +896,3 @@ void print_todo_header(FILE *f)
     fputs(todo_header, f);
 }
 
-/*----------------------------------------------------------------------*/
