@@ -1,4 +1,4 @@
-/* $Id: utils.h,v 1.61 2008/04/29 14:21:24 rikster5 Exp $ */
+/* $Id: utils.h,v 1.69 2008/09/21 19:06:47 rikster5 Exp $ */
 
 /*******************************************************************************
  * utils.h
@@ -43,28 +43,15 @@
 #define PRINT_FILE_LINE printf("%s line %d\n", __FILE__, __LINE__)
 
 #ifdef ENABLE_PROMETHEON
-#define PN "CoPilot"
+#  define PN "CoPilot"
+#  define EPN "copilot"
 #else
-#define PN "J-Pilot"
-#endif
-
-#ifdef ENABLE_PROMETHEON
-#define EPN "copilot"
-#else
-#define EPN "jpilot"
+#  define PN "J-Pilot"
+#  define EPN "jpilot"
 #endif
 
 #define	FPI_STRING	"-//Judd Montgomery//NONSGML "PN" "VERSION"//EN"
 
-/* GTK 1 seems to have a problem with reading and setting the pane
- * differing by 2 pixels.  This may not be true on every system.
- */
-#ifdef ENABLE_GTK2
-# define PANE_CREEP 0
-#else
-# define PANE_CREEP 2
-#endif
-
 /*This is how often the clock updates in milliseconds */
 #define CLOCK_TICK 1000
 
@@ -73,7 +60,7 @@
 #define SHADOW GTK_SHADOW_ETCHED_OUT
 
 /*
- *          JPA define the maximum length of a category name
+ *             define the maximum length of a category name
  *             when expressed in Pilot character set (assuming 15
  *             character plus a delimiter) or in host character
  *             set (might be 50 or more if UTF-8).
@@ -82,9 +69,9 @@
  *             names may be (hopefully safely) truncated.
  */
 
-#define HOSTCATLTH 16
-#define PILOTCATLTH 16
-#define CATCOUNT 16 /* number of categories */
+#define NUM_CATEGORIES 16 
+#define HOSTCAT_NAME_SZ 16
+#define PILOTCAT_NAME_SZ 16
 
 /*Used to mark the entry in the clist to add a record */
 /* FIXME: Move to libplugin */
@@ -150,9 +137,7 @@
 #define DAT_MEMO_FILE        13
 
 /* Pilot-link 0.12 is broken and missing pi_uid_t */
-#ifdef PILOT_LINK_0_12
 typedef recordid_t pi_uid_t;
-#endif
 
 extern unsigned int glob_find_id;
 
@@ -379,13 +364,7 @@ int import_record_ask(GtkWidget *main_window, GtkWidget *pane,
 		      char *old_cat_name,
 		      int priv, int suggested_cat_num, int *new_cat_num);
 
-/* could be in dat.h or import.h */
-#define DAT_TYPE_INTEGER 1
-#define DAT_TYPE_CSTRING 5
-#define DAT_TYPE_DATE    3
-#define DAT_TYPE_BOOLEAN 6
-#define DAT_TYPE_BITFLAG 7
-#define DAT_TYPE_REPEAT  8
+int verify_csv_header(const char *header, int num_fields, const char *file_name);
 
 /* Returns a dat type, or 0 */
 int dat_check_if_dat_file(FILE *in);
@@ -450,7 +429,7 @@ void ldif_out(FILE *f, char *name, char *fmt, ...);
 /*
  * Output base64-encoded string to file
  */
-void base64_out(FILE *, char *);
+void base64_out(FILE *, unsigned char *);
 
 void cleanup_path(char *path);
 
@@ -539,27 +518,16 @@ int pdb_file_modify_record(char *DB_name, void *record_in, int size_in,
  * attrp is the attributes
  * catp is the category (index)
  */
-#ifdef PILOT_LINK_0_12
 int pdb_file_read_record_by_id(char *DB_name, 
 			       pi_uid_t uid,
 			       void **bufp, size_t *sizep, int *idxp,
 			       int *attrp, int * catp);
-#else
-int pdb_file_read_record_by_id(char *DB_name, 
-			       pi_uid_t uid,
-			       void **bufp, int *sizep, int *idxp,
-			       int *attrp, int * catp);
-#endif
 /*
  * DB_name should be without filename ext, e.g. MemoDB
  * bufp is the packed app info block
  * size_in is the size of bufp
  */
-#ifdef PILOT_LINK_0_12
 int pdb_file_write_app_block(char *DB_name, void *bufp, size_t size_in);
-#else
-int pdb_file_write_app_block(char *DB_name, void *bufp, int size_in);
-#endif
 
 /*
  * This copies the database (pdb, or prc) and writes the DBInfo privided
@@ -584,19 +552,18 @@ int edit_cats(GtkWidget *widget, char *db_name, struct CategoryAppInfo *cai);
  * returns the number of record's categories changed.
  */
 int pdb_file_change_indexes(char *DB_name, int old_index, int new_index);
-int edit_cats_change_cats_pc3(char *DB_name, int old_cat,
-			      int new_cat);
-int edit_cats_swap_cats_pc3(char *DB_name, int old_cat,
-			    int new_cat);
+int pdb_file_swap_indexes(char *DB_name, int old_cat, int new_cat);
+int edit_cats_change_cats_pc3(char *DB_name, int old_cat, int new_cat);
+int edit_cats_swap_cats_pc3(char *DB_name, int old_cat, int new_cat);
 int edit_cats_change_cats_pdb(char *DB_name, int old_cat, int new_cat);
 
-  
 int make_category_menu(GtkWidget **category_menu,
 		       GtkWidget **cat_menu_item,
 		       struct sorted_cats *sort_l,
 		       void (*selection_callback)
 		       (GtkWidget *item, int selection),
-		       int add_an_all_item);
+		       int add_an_all_item,
+		       int add_edit_cat_item);
 
 void multibyte_safe_strncpy(char *dst, char *src, size_t len);
 char *multibyte_safe_memccpy(char *dst, const char *src, int c, size_t len);
@@ -613,7 +580,4 @@ char *charset_p2newj(const char *buf, int max_len, int char_set);
 
 void jp_charset_p2j(char *buf, int max_len);
 size_t jp_strftime(char *s, size_t max, const char *format, const struct tm *tm);
-#ifndef ENABLE_GTK2
-size_t g_strlcpy(char *dst, const char *src, size_t siz);
-#endif
 #endif
